@@ -21,6 +21,8 @@ def local_css(file_name):
 
 target_css = os.path.join(os.path.dirname(__file__), 'style.css')
 
+st.set_option('deprecation.showPyplotGlobalUse', False)
+
 local_css(target_css)
 
 st.markdown('<style>div.Widget.row-widget.stRadio> div{flex-direction:row;}</style>', unsafe_allow_html=True)
@@ -46,9 +48,6 @@ Feel free to customize as needed. </p>
 - Highly <span class='fontteal'>**Customizable**</span>
 - No more static reports<br>
 
-<b>Plans for Aug-Sep 2020</b>
-- Filtering Data
-- Overall Performance improvement
 """
 
 hide_streamlit_style = """
